@@ -1,7 +1,7 @@
 package Vimana::Command::Rate;
 use warnings;
 use strict;
-use base qw(App::CLI::Command);
+use parent qw(App::CLI::Command);
 use LWP::Simple;
 sub options {
     ();
